@@ -2,7 +2,7 @@ from django.contrib import admin
 from django.utils.translation import pgettext_lazy
 from django.db import models
 from prettyjson import PrettyJSONWidget
-from django.templatetags.l10n import localize
+from django.utils import timezone, formats
 
 from .models import Log
 
@@ -37,7 +37,8 @@ class LogAdmin(admin.ModelAdmin):
 
     def created_at_extended(self, obj):
         return '{} {}'.format(
-            localize(obj.created_at), obj.created_at.strftime('%S.%f'),
+            formats.localize(timezone.template_localtime(obj.created_at)),
+            obj.created_at.strftime('%S.%f'),
         )
 
     created_at_extended.admin_order_field = 'created_at'
