@@ -5,6 +5,7 @@ import logging
 from uuid import UUID
 from functools import wraps
 from px_domains import Domain
+from django.http import RawPostDataException
 
 from django.http import HttpRequest, HttpResponse
 
@@ -57,6 +58,8 @@ def resolve_request_data(request: HttpRequest) -> Dict:
             ) else
             {}
         )
+    except RawPostDataException as e:
+        pass
     except Exception as e:
         logger.exception(e)
         data_body = {}
